#!/bin/bash

# Logging details
BASE_RESULTS_DIR=/home/jenkins/results
LOGGING_FILE=$BASE_RESULTS_DIR/artifacts/ap_test_debug_log.txt
INSTALLED_LOG=$BASE_RESULTS_DIR/artifacts/UNITY_NOT_INSTALLED

# Execution details
TEST_LIST_FILE=/home/jenkins/ap_test_list.txt
CREATE_TEST_LIST="autopilot list unity | grep unity.tests | cut -d. -f2,3 | sort | uniq | sed 's/^/unity./'"
FINISHED_FLAG=/home/jenkins/.ap_tests_finished

# setup
export http_proxy="http://91.189.90.174:3128/"
export https_proxy="http://91.189.90.174:3128/"
gsettings set com.ubuntu.update-notifier show-apport-crashes false

mkdir -p $BASE_RESULTS_DIR $BASE_RESULTS_DIR/testresults $BASE_RESULTS_DIR/artifacts

if [ -e $FINISHED_FLAG ]; then
    echo "Complete!"
    exit 0
fi

# Create the test list if required
# Plus hack to disable 2nd monitor (Intel machine) for now
#   will do something smarter, just at the moment is mirrored and is screwing up
#   the results. One thing at a time
if [ ! -e $TEST_LIST_FILE ]; then
    echo $(eval $CREATE_TEST_LIST) &>> $TEST_LIST_FILE

    $(/usr/local/bin/setup_monitors.sh &>> $LOGGING_FILE)
    sleep 5  # Ensure the monitors are all settled down
fi

# Grab this test and trim it from the list
THIS_TEST=$(cut -d" " -f1 $TEST_LIST_FILE)
echo $(cut -d" " -f2- $TEST_LIST_FILE) > $TEST_LIST_FILE

echo "Detect if additional packages have been installed" &>> $LOGGING_FILE
if ! /usr/local/bin/detect_additional_packages &>> $LOGGING_FILE; then
    echo "More packages than expected have been installed, there is maybe an ABI breakage, this stack can't be tested alone."
    echo 1 > $FINISHED_FLAG
    exit 1
fi

echo "Waiting for Unity" &>> $LOGGING_FILE
if ! /usr/local/bin/wait_for_unity.py; then
    echo "Unity seems to be unavailable (for test suite: $THIS_TEST)" &>> $LOGGING_FILE
    echo 1 > $FINISHED_FLAG
    exit 1
fi

# Run the command
echo Starting suite: $THIS_TEST &>> $LOGGING_FILE
autopilot run -v -r -rd $BASE_RESULTS_DIR/artifacts \
    -f xml -o $BASE_RESULTS_DIR/testresults/$THIS_TEST-result.xml \
    $THIS_TEST \
    &>> $LOGGING_FILE

# Check if this is the final test to run, mark us for completion if so
if [ $(cat $TEST_LIST_FILE | wc -w) -eq 1 ]; then
    echo 0 > $FINISHED_FLAG
else
    # Restart unity between tests
    sudo service lightdm restart
fi
